summaryrefslogtreecommitdiff
path: root/src/rebar_erlc_compiler.erl
diff options
context:
space:
mode:
Diffstat (limited to 'src/rebar_erlc_compiler.erl')
-rw-r--r--src/rebar_erlc_compiler.erl15
1 files changed, 7 insertions, 8 deletions
diff --git a/src/rebar_erlc_compiler.erl b/src/rebar_erlc_compiler.erl
index fe06cbf..8b63321 100644
--- a/src/rebar_erlc_compiler.erl
+++ b/src/rebar_erlc_compiler.erl
@@ -70,13 +70,12 @@
-spec compile(Config::rebar_config:config(), AppFile::file:filename()) -> 'ok'.
compile(Config, _AppFile) ->
- %% TODO: enable as soon as OTP patch has been accepted
- %% ?DEPRECATED(fail_on_warning, warnings_as_errors,
- %% rebar_config:get_list(Config, xrl_opts, []),
- %% "once R15 is released"),
- %% ?DEPRECATED(fail_on_warning, warnings_as_errors,
- %% rebar_config:get_list(Config, yrl_opts, []),
- %% "once R15 is released"),
+ ?DEPRECATED(xrl_opts, fail_on_warning, warnings_as_errors,
+ rebar_config:get_list(Config, xrl_opts, []),
+ "once R14B04 is released"),
+ ?DEPRECATED(yrl_opts, fail_on_warning, warnings_as_errors,
+ rebar_config:get_list(Config, yrl_opts, []),
+ "once R14B04 is released"),
rebar_base_compiler:run(Config,
check_files(rebar_config:get_local(
@@ -299,7 +298,7 @@ compile_xrl_yrl(Source, Target, Opts, Mod) ->
{ok, _, []} ->
ok;
{ok, _, _Warnings} ->
%% TODO: remove once R15 is released
case lists:member(fail_on_warning, Opts) of
true ->
?FAIL;
@@ -299,7 +298,7 @@ compile_xrl_yrl(Source, Target, Opts, Mod) ->
ok;
{ok, _, _Warnings} ->
- %% TODO: remove once R15 is released
+ %% TODO: remove once R14B04 is released
case lists:member(fail_on_warning, Opts) of
true ->